<?php

/**
 * @author Artem Parfenov <dziro@mail.ru> https://t.me/Dzirosh
 * @copyright 2024 Artem Parfenov
 */

class ControllerExtensionPaymentAirbapay extends Controller
{
	private $error = [];

	public function index()
    {
		$lng = $this->load->language('extension/payment/airbapay');

        foreach ($lng as $k => $v) $data[$k] = $this->language->get($k);

		$this->document->setTitle($this->language->get('heading_title'));

		$this->load->model('setting/setting');

		if (($this->request->server['REQUEST_METHOD'] == 'POST') && $this->validate()) {
			$this->model_setting_setting->editSetting('airbapay', $this->request->post);

			$this->session->data['success'] = $this->language->get('text_success');

			$this->response->redirect($this->url->link('extension/extension', 'token=' . $this->session->data['token'] . '&type=payment', true));
		}

		if (isset($this->error['warning'])) $data['error_warning'] = $this->error['warning'];
		else $data['error_warning'] = '';

        if (isset($this->error['user'])) $data['error_user'] = $this->error['user'];
        else $data['error_user'] = '';

        if (isset($this->error['password'])) $data['error_password'] = $this->error['password'];
        else $data['error_password'] = '';

        if (isset($this->error['terminal_id'])) $data['error_terminal_id'] = $this->error['terminal_id'];
        else $data['error_terminal_id'] = '';

        if (isset($this->error['success_back_url'])) $data['error_success_back_url'] = $this->error['success_back_url'];
        else $data['error_success_back_url'] = '';

        if (isset($this->error['failure_back_url'])) $data['error_failure_back_url'] = $this->error['failure_back_url'];
        else $data['error_failure_back_url'] = '';

        if (isset($this->error['success_callback'])) $data['error_success_callback'] = $this->error['success_callback'];
        else $data['error_success_callback'] = '';

		if (isset($this->error['failure_callback'])) $data['error_failure_callback'] = $this->error['failure_callback'];
		else $data['error_failure_callback'] = '';

		$data['breadcrumbs'] = [];

		$data['breadcrumbs'][] = [
			'text' => $this->language->get('text_home'),
			'href' => $this->url->link('common/dashboard', 'token=' . $this->session->data['token'], true)
		];

		$data['breadcrumbs'][] = [
			'text' => $this->language->get('text_extension'),
			'href' => $this->url->link('extension/extension', 'token=' . $this->session->data['token'] . '&type=payment', true)
		];

		$data['breadcrumbs'][] = [
			'text' => $this->language->get('heading_title'),
			'href' => $this->url->link('extension/payment/airbapay', 'token=' . $this->session->data['token'], true)
		];

		$data['action'] = $this->url->link('extension/payment/airbapay', 'token=' . $this->session->data['token'], true);
		$data['cancel'] = $this->url->link('extension/extension', 'token=' . $this->session->data['token'] . '&type=payment', true);

        if (isset($this->request->post['airbapay_user'])) $data['airbapay_user'] = $this->request->post['airbapay_user'];
        else $data['airbapay_user'] = $this->config->get('airbapay_user');

        if (isset($this->request->post['airbapay_password'])) $data['airbapay_password'] = $this->request->post['airbapay_password'];
        else $data['airbapay_password'] = $this->config->get('airbapay_password');

        if (isset($this->request->post['airbapay_terminal_id'])) $data['airbapay_terminal_id'] = $this->request->post['airbapay_terminal_id'];
        else $data['airbapay_terminal_id'] = $this->config->get('airbapay_terminal_id');

        if (isset($this->request->post['airbapay_auto_charge'])) $data['airbapay_auto_charge'] = $this->request->post['airbapay_auto_charge'];
        else $data['airbapay_auto_charge'] = $this->config->get('airbapay_auto_charge') !== null ? $this->config->get('airbapay_auto_charge') : 1;

        if (isset($this->request->post['airbapay_success_back_url'])) $data['airbapay_success_back_url'] = $this->request->post['airbapay_success_back_url'];
        else $data['airbapay_success_back_url'] = $this->config->get('airbapay_success_back_url') ? $this->config->get('airbapay_success_back_url') : HTTPS_CATALOG.'?route=checkout/success';

        if (isset($this->request->post['airbapay_failure_back_url'])) $data['airbapay_failure_back_url'] = $this->request->post['airbapay_failure_back_url'];
        else $data['airbapay_failure_back_url'] = $this->config->get('airbapay_failure_back_url') ? $this->config->get('airbapay_failure_back_url') : HTTPS_CATALOG.'?route=checkout/failure';

        if (isset($this->request->post['airbapay_success_callback'])) $data['airbapay_success_callback'] = $this->request->post['airbapay_success_callback'];
        else $data['airbapay_success_callback'] = $this->config->get('airbapay_success_callback') ? $this->config->get('airbapay_success_callback') : HTTPS_CATALOG.'?route=extension/payment/airbapay/callback&success';

        if (isset($this->request->post['airbapay_failure_callback'])) $data['airbapay_failure_callback'] = $this->request->post['airbapay_failure_callback'];
        else $data['airbapay_failure_callback'] = $this->config->get('airbapay_failure_callback') ? $this->config->get('airbapay_failure_callback') : HTTPS_CATALOG.'?route=extension/payment/airbapay/callback&failure';

        if (isset($this->request->post['airbapay_mode'])) $data['airbapay_mode'] = $this->request->post['airbapay_mode'];
        else $data['airbapay_mode'] = $this->config->get('airbapay_mode') !== null ? $this->config->get('airbapay_mode') : 1;

		if (isset($this->request->post['airbapay_order_status_id'])) $data['airbapay_order_status_id'] = $this->request->post['airbapay_order_status_id'];
		else $data['airbapay_order_status_id'] = $this->config->get('airbapay_order_status_id');

		$this->load->model('localisation/order_status');

		$data['order_statuses'] = $this->model_localisation_order_status->getOrderStatuses();

		if (isset($this->request->post['airbapay_geo_zone_id'])) $data['airbapay_geo_zone_id'] = $this->request->post['airbapay_geo_zone_id'];
		else $data['airbapay_geo_zone_id'] = $this->config->get('airbapay_geo_zone_id');

		$this->load->model('localisation/geo_zone');

		$data['geo_zones'] = $this->model_localisation_geo_zone->getGeoZones();

		if (isset($this->request->post['airbapay_status'])) $data['airbapay_status'] = $this->request->post['airbapay_status'];
		else $data['airbapay_status'] = $this->config->get('airbapay_status');

		if (isset($this->request->post['airbapay_sort_order'])) $data['airbapay_sort_order'] = $this->request->post['airbapay_sort_order'];
		else $data['airbapay_sort_order'] = $this->config->get('airbapay_sort_order');

		$data['header'] = $this->load->controller('common/header');
		$data['column_left'] = $this->load->controller('common/column_left');
		$data['footer'] = $this->load->controller('common/footer');

		$this->response->setOutput($this->load->view('extension/payment/airbapay', $data));
	}

	protected function validate()
    {
		if (!$this->user->hasPermission('modify', 'extension/payment/airbapay')) $this->error['warning'] = $this->language->get('error_permission');

        if (!$this->request->post['airbapay_user']) $this->error['user'] = $this->language->get('error_user');
        if (!$this->request->post['airbapay_password']) $this->error['password'] = $this->language->get('error_password');
        if (!$this->request->post['airbapay_terminal_id']) $this->error['terminal_id'] = $this->language->get('error_terminal_id');

        if (!$this->request->post['airbapay_success_back_url']) $this->error['success_back_url'] = $this->language->get('error_success_back_url');
        if (!$this->request->post['airbapay_failure_back_url']) $this->error['failure_back_url'] = $this->language->get('error_failure_back_url');
        if (!$this->request->post['airbapay_success_callback']) $this->error['success_callback'] = $this->language->get('error_success_callback');
		if (!$this->request->post['airbapay_failure_callback']) $this->error['failure_callback'] = $this->language->get('error_failure_callback');

		return !$this->error;
	}
}